FromFrame

Derive Macro FromFrame 

#[derive(FromFrame)]
{
    // Attributes available to this derive:
    #[frame]
}
Derives FromFrame for a struct, enabling deserialization from a Frame.

Generated code references types from the reifydb crate.

Attributes

  • #[frame(column = "name")] - Use a different column name than the field name
  • #[frame(optional)] - Field is optional; missing columns or None values become None
  • #[frame(coerce)] - Use widening type coercion for this field
  • #[frame(skip)] - Skip this field (must implement Default)